@@ -1,37 +1,19 @@
-## ----openLibrary, echo=FALSE------------------------------
-library(xtable)
-options(continue=" ")
-options(width=60)
-library(knitr)
+## ----include=TRUE ,echo=FALSE,eval=TRUE, message=FALSE, warning=FALSE---------
+
 library(EGRET)
+library(knitr)
 
-## ----include=TRUE ,echo=FALSE,eval=TRUE, message=FALSE, warning=FALSE----
-opts_chunk$set(highlight=TRUE,
-               keep.space=TRUE, 
-               keep.blank.space=FALSE, 
-               keep.comment=TRUE, 
-               concordance=TRUE,
-               tidy=FALSE,
-               comment="",
-               eval = nzchar(Sys.getenv("EGRET_eval")))
-
-knit_hooks$set(inline = function(x) {
-   if (is.numeric(x)) round(x, 3)})
-
-knit_hooks$set(crop = hook_pdfcrop)
+knitr::opts_chunk$set(echo = TRUE, 
+                      warning = FALSE, 
+                      message = FALSE,
+                      fig.height=7,
+                      fig.width=7,
+                      out.width = "45%",
+                      fig.show = 'hold',
+                      fig.align = 'center')
 
 
-bold.colHeaders <- function(x) {
-  x <- gsub("\\^(\\d)","$\\^\\1$",x)
-  x <- gsub("\\%","\\\\%",x)
-  x <- gsub("\\_"," ",x)
-  returnX <- paste("\\multicolumn{1}{c}{\\textbf{\\textsf{", x, "}}}", sep = "")
-}
-
-addSpace <- function(x) ifelse(x != "1", "[5pt]","")
-
-
-## ----workflowFlowHistory, echo=TRUE,eval=FALSE------------
+## ----workflowFlowHistory, echo=TRUE,eval=FALSE--------------------------------
 #  library(EGRET)
 #  
 #  # Flow history analysis
@@ -64,7 +46,7 @@ addSpace <- function(x) ifelse(x != "1", "[5pt]","")
 #  saveResults(savePath, eList)
 #  
 
-## ----workflowWaterQuality, echo=TRUE,eval=FALSE-----------
+## ----workflowWaterQuality, echo=TRUE,eval=FALSE-------------------------------
 #  library(EGRET)
 #  
 #  ############################
@@ -124,20 +106,20 @@ addSpace <- function(x) ifelse(x != "1", "[5pt]","")
 #  plotFluxHist(eList)
 #  
 #  # Multi-line plots:
-#  date1 <- "2000-09-01"
-#  date2 <- "2005-09-01"
-#  date3 <- "2009-09-01"
-#  qBottom<-5
-#  qTop<-1000
+#  date1 <- "1985-09-01"
+#  date2 <- "1997-09-0"
+#  date3 <- "2010-09-01"
+#  qBottom<-0.2
+#  qTop<-10
 #  plotConcQSmooth(eList, date1, date2, date3, qBottom, qTop,
-#                     concMax=2,qUnit=1)
-#  q1 <- 10
-#  q2 <- 25
-#  q3 <- 75
+#                     concMax=2,legendTop = 0.8)
+#  q1 <- 2
+#  q2 <- 10
+#  q3 <- 20
 #  centerDate <- "07-01"
-#  yearEnd <- 2009
-#  yearStart <- 2000
-#  plotConcTimeSmooth(eList, q1, q2, q3, centerDate, yearStart, yearEnd)
+#  yearEnd <- 1980
+#  yearStart <- 2010
+#  plotConcTimeSmooth(eList, q1, q2, q3, centerDate, yearStart, yearEnd, legendTop = 0.7)
 #  
 #  # Multi-plots:
 #  fluxBiasMulti(eList)
@@ -145,63 +127,63 @@ addSpace <- function(x) ifelse(x != "1", "[5pt]","")
 #  #Contour plots:
 #  clevel<-seq(0,2,0.5)
 #  maxDiff<-0.8
-#  yearStart <- 2000
+#  yearStart <- 1980
 #  yearEnd <- 2010
 #  
 #  plotContours(eList, yearStart,yearEnd,qBottom,qTop,
-#               contourLevels = clevel,qUnit=1)
+#               contourLevels = clevel,qUnit=2)
 #  plotDiffContours(eList, yearStart,yearEnd,
-#                   qBottom,qTop,maxDiff,qUnit=1)
+#                   qBottom,qTop,maxDiff,qUnit=2)
 #  
 #  # modify this for your own computer file structure:
 #  savePath<-"/Users/rhirsch/Desktop/"
 #  saveResults(savePath, eList)
 
-## ----openDataRetrieval, eval=FALSE------------------------
+## ----openDataRetrieval, eval=FALSE--------------------------------------------
 #  library(dataRetrieval)
 #  vignette("dataRetrieval")
 
-## ----openlibraries, echo=TRUE,eval=FALSE------------------
+## ----openlibraries, echo=TRUE,eval=FALSE--------------------------------------
 #  library(EGRET)
 
-## ----firstExample, echo=TRUE, eval=FALSE------------------
+## ----firstExample, echo=TRUE, eval=FALSE--------------------------------------
 #  siteNumber <- "01491000"
 #  startDate <- "2000-01-01"
 #  endDate <- "2013-01-01"
 #  # This call will get NWIS (ft3/s) data , and convert it to m3/s:
 #  Daily <- readNWISDaily(siteNumber, "00060", startDate, endDate)
 
-## ----openDaily, eval = FALSE------------------------------
+## ----openDaily, eval = FALSE--------------------------------------------------
 #  fileName <- "ChoptankRiverFlow.txt"
 #  filePath <-  "C:/RData/"
-#  Daily <-readDataFromFile(filePath,fileName,
+#  Daily <- readUserDaily(filePath,fileName,
 #                      separator="\t")
 
-## ----secondExample,echo=TRUE,eval=FALSE-------------------
+## ----secondExample,echo=TRUE,eval=FALSE---------------------------------------
 #  siteNumber <- "01491000"
 #  parameterCd <- "00618"
 #  Sample <-readNWISSample(siteNumber,parameterCd,
 #        startDate, endDate)
 
-## ----STORET,echo=TRUE,eval=FALSE--------------------------
+## ----STORET,echo=TRUE,eval=FALSE----------------------------------------------
 #  site <- 'WIDNR_WQX-10032762'
 #  characteristicName <- 'Specific conductance'
 #  Sample <-readWQPSample(site,characteristicName,
 #        startDate, endDate)
 
-## ----openSample, eval = FALSE-----------------------------
+## ----openSample, eval = FALSE-------------------------------------------------
 #  fileName <- "ChoptankRiverNitrate.csv"
 #  filePath <-  "C:/RData/"
-#  Sample <-readUserSample(filePath,fileName,
+#  Sample <- readUserSample(filePath,fileName,
 #                                  separator=",")
 
-## ----openSample2, eval = FALSE----------------------------
+## ----openSample2, eval = FALSE------------------------------------------------
 #  fileName <- "ChoptankPhosphorus.txt"
 #  filePath <-  "C:/RData/"
 #  Sample <-readUserSample(filePath,fileName,
 #                                  separator="\t")
 
-## ----label=tab:exampleComplexQW, echo=FALSE, eval=TRUE,results='asis'----
+## ----label=tab:exampleComplexQW, echo=FALSE, eval=TRUE,results='asis'---------
 cdate <- c("2003-02-15","2003-06-30","2004-09-15","2005-01-30","2005-05-30","2005-10-30")
 rdp <- c("", "<","<","","","")
 dp <- c(0.02,0.01,0.005,NA,NA,NA)
@@ -212,34 +194,27 @@ tp <- c(NA,NA,NA,0.43,0.05,0.02)
 
 DF <- data.frame(cdate,rdp,dp,rpp,pp,rtp,tp,stringsAsFactors=FALSE)
 
-xTab <- xtable(DF, caption="Example data",digits=c(0,0,0,3,0,3,0,3),label="tab:exampleComplexQW")
-
-print(xTab,
-       caption.placement="top",
-       size = "\\footnotesize",
-       latex.environment=NULL,
-       sanitize.colnames.function =  bold.colHeaders,
-       sanitize.rownames.function = addSpace
-      )
+knitr::kable(DF,  caption="Example data", 
+                     digits=c(0,0,0,3,0,3,0,3))
 
 
-## ----thirdExample,echo=FALSE------------------------------
+## ----thirdExample,echo=FALSE--------------------------------------------------
   compressedData <- compressData(DF)
   Sample <- populateSampleColumns(compressedData)
 
-## ----thirdExampleView,echo=TRUE---------------------------
+## ----thirdExampleView,echo=TRUE-----------------------------------------------
   Sample
 
-## ----ThirdExample, eval=FALSE-----------------------------
+## ----ThirdExample, eval=FALSE-------------------------------------------------
 #  parameterCd <- "00618"
 #  siteNumber <- "01491000"
 #  INFO <- readNWISInfo(siteNumber,parameterCd, interactive=FALSE)
 
-## ----WQPInfo, eval=FALSE----------------------------------
+## ----WQPInfo, eval=FALSE------------------------------------------------------
 #  parameterCd <- "00618"
 #  INFO_WQP <- readWQPInfo("USGS-01491000",parameterCd)
 
-## ----addInfoCustom, eval=FALSE, echo=TRUE-----------------
+## ----addInfoCustom, eval=FALSE, echo=TRUE-------------------------------------
 #  
 #  fileName <- "INFO.csv"
 #  filePath <- "C:/RData/"
@@ -247,13 +222,13 @@ print(xTab,
 #  INFO <- readUserInfo(filePath, fileName)
 #  
 
-## ----addInfo, eval=FALSE, echo=TRUE-----------------------
+## ----addInfo, eval=FALSE, echo=TRUE-------------------------------------------
 #  
 #  INFO$riverInfo <- "Major tributary of the Chesapeake Bay"
 #  INFO$GreensboroPopulation <- 1931
 #  
 
-## ----mergeExample, eval=FALSE-----------------------------
+## ----mergeExample, eval=FALSE-------------------------------------------------
 #  siteNumber <- "01491000"
 #  parameterCd <- "00631"  # Nitrate
 #  startDate <- "2000-01-01"
@@ -263,39 +238,33 @@ print(xTab,
 #  Sample <- readNWISSample(siteNumber,parameterCd, startDate, endDate)
 #  INFO <- readNWISInfo(siteNumber, parameterCd)
 #  
-#  
 #  eList <- mergeReport(INFO, Daily,Sample)
-#  
 
-## ----egretObedit, echo=TRUE, eval=FALSE-------------------
-#  
+## ----egretObedit, echo=TRUE, eval=FALSE---------------------------------------
 #  eListNew <- as.egret(INFO, Daily, Sample, surfaces)
-#  
 #  #To pull out the INFO data frame:
 #  INFO <- getInfo(eListNew)
 #  #Edit the INFO data frame:
 #  INFO$importantNews <- "New EGRET workflow started"
 #  #Put new data frame in eListNew
 #  eListNew$INFO <- INFO
-#  
 #  #To pull out Daily:
 #  Daily <- getDaily(eListNew)
 #  #Edit for some reason:
 #  DailyNew <- Daily[Daily$DecYear > 1985,]
 #  #Put new Daily data frame back in eListNew:
 #  eListNew$Daily <- DailyNew
-#  
 #  #To create a whole new egret object:
 #  eList_2 <- as.egret(INFO, DailyNew, getSample(eListNew), NA)
 #  
 
-## ----cheatSheets,echo=TRUE,eval=TRUE,results='markup'-----
+## ----cheatSheets,echo=TRUE,eval=TRUE,results='markup'-------------------------
 printqUnitCheatSheet()
 
-## ----cheatSheets2,echo=TRUE,eval=TRUE,results='markup'----
+## ----cheatSheets2,echo=TRUE,eval=TRUE,results='markup'------------------------
 printFluxUnitCheatSheet()
 
-## ----flowHistory,echo=TRUE,eval=FALSE---------------------
+## ----flowHistory,echo=TRUE,eval=FALSE-----------------------------------------
 #  siteNumber <- "14105700"
 #  startDate <- ""
 #  endDate <- ""
@@ -305,25 +274,23 @@ printFluxUnitCheatSheet()
 #  INFO$shortName <- "Columbia River at The Dalles, OR"
 #  
 #  eList <- as.egret(INFO, Daily, NA, NA)
-#  
 
-## ----flowHistoryLoad,echo=FALSE---------------------------
+## ----flowHistoryLoad,echo=FALSE-----------------------------------------------
 fileName <- "eListColumbia.RData"
 load(fileName)
 eList <- eListColumbia
 
-
-## ----newChunckWinter, echo=TRUE,eval=FALSE----------------
+## ----newChunckWinter, echo=TRUE,eval=FALSE------------------------------------
 #  eList <- setPA(eList,paStart=12,paLong=3)
 
-## ----newChunck, echo=TRUE---------------------------------
+## ----newChunck, echo=TRUE-----------------------------------------------------
 eList <- setPA(eList)
 
-## ----plotSingleandSD, echo=TRUE, fig.cap="Plots of discharge statistics",fig.subcap=c("plotFlowSingle(eList, istat=5,qUnit='thousandCfs')","plotSDLogQ(eList)"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h",cache=TRUE----
+## ----plotSingleandSD, echo=TRUE, fig.cap="Plots of discharge statistics"------
 plotFlowSingle(eList, istat=5,qUnit="thousandCfs")
 plotSDLogQ(eList)
 
-## ----Merced, echo=TRUE,eval=FALSE-------------------------
+## ----Merced, echo=TRUE,eval=FALSE---------------------------------------------
 #  # Merced River at Happy Isles Bridge, CA:
 #  siteNumber<-"11264500"
 #  Daily <-readNWISDaily(siteNumber,"00060",startDate="",endDate="")
@@ -331,27 +298,26 @@ plotSDLogQ(eList)
 #  INFO$shortName <- "Merced River at Happy Isles Bridge, CA"
 #  eList <- as.egret(INFO, Daily, NA, NA)
 
-## ----Merceddata, echo=FALSE-------------------------------
+## ----Merceddata, echo=FALSE---------------------------------------------------
 fileName <- "eListMerced.RData"
 load(fileName)
 eList <- eListMerced
 
-## ----Mercedplot, echo=TRUE,fig.cap="Merced River winter trend",fig.subcap=c("Water Year", "December - February"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----Mercedplot, echo=TRUE,fig.cap="Merced River winter trend"----------------
 plotFlowSingle(eList, istat=5)
-
 # Then, we can run the same function, but first set 
 # the pa to start in December and only run for 3 months.
 eListMerced <- setPA(eList,paStart=12,paLong=3)
 plotFlowSingle(eListMerced,istat=5,qMax=200)
 
 
-## ----plotFour, echo=TRUE, fig.cap="\\texttt{plotFour(eListMerced, qUnit=3)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----plotFour, echo=TRUE, fig.cap="`plotFour(eListMerced, qUnit=3)`", out.width="100%"----
 plotFour(eList, qUnit=3)
 
-## ----plotFourStats,echo=TRUE, fig.cap="\\texttt{plotFourStats(eListMerced, qUnit=3)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h",cache=TRUE----
+## ----plotFourStats,echo=TRUE,out.width="100%", fig.cap="`plotFourStats(eListMerced, qUnit=3)`"----
 plotFourStats(eList, qUnit=3)
 
-## ----MississippiData, echo=TRUE,eval=FALSE----------------
+## ----MississippiData, echo=TRUE,eval=FALSE------------------------------------
 #  #Mississippi River at Keokuk Iowa:
 #  siteNumber<-"05474500"
 #  Daily <-readNWISDaily(siteNumber,"00060",startDate="",endDate="")
@@ -359,23 +325,22 @@ plotFourStats(eList, qUnit=3)
 #  INFO$shortName <- "Mississippi River at Keokuk Iowa"
 #  eList <- as.egret(INFO, Daily, NA, NA)
 
-## ----MissDataRetrieval, echo=FALSE------------------------
+## ----MissDataRetrieval, echo=FALSE--------------------------------------------
 fileName <- "eListMiss.RData"
 load(fileName)
 eList <- eListMiss
 
-## ----MississippiPlot, echo=TRUE,fig.cap="Mississippi River at Keokuk Iowa",fig.subcap=c("Water Year", "Dec-Feb"),out.width='1\\linewidth',out.height='1\\linewidth',fig.show='hold',fig.pos="h"----
-
+## ----MississippiPlot, echo=TRUE,fig.cap="Mississippi River at Keokuk Iowa"----
 plotQTimeDaily(eList, qUnit=3,qLower=300)
 
 
-## ----printSeries, eval=FALSE,echo=TRUE--------------------
+## ----printSeries, eval=FALSE,echo=TRUE----------------------------------------
 #  seriesResult <- printSeries(eList, istat=3, qUnit=3)
 
-## ----tfc, echo=TRUE---------------------------------------
+## ----tfc, echo=TRUE-----------------------------------------------------------
 tableFlowChange(eList, istat=3, qUnit=3,yearPoints=c(1890,1950,2010))
 
-## ----wrtds1,eval=FALSE,echo=TRUE--------------------------
+## ----wrtds1,eval=FALSE,echo=TRUE----------------------------------------------
 #  #Choptank River at Greensboro, MD:
 #  siteNumber <- "01491000"
 #  startDate <- "1979-10-01"
@@ -388,7 +353,7 @@ tableFlowChange(eList, istat=3, qUnit=3,yearPoints=c(1890,1950,2010))
 #  Sample <- readNWISSample(siteNumber,param,startDate,endDate)
 #  eList <- mergeReport(INFO, Daily, Sample)
 
-## ----wrtds2,eval=TRUE,echo=FALSE--------------------------
+## ----wrtds2,eval=TRUE,echo=FALSE----------------------------------------------
 siteNumber <- "01491000" #Choptank River at Greensboro, MD
 startDate <- "1979-10-01"
 endDate <- "2011-09-30"
@@ -399,34 +364,34 @@ Sample <- getSample(eList)
 INFO <- getInfo(eList)
 
 
-## ----plotBoxes, echo=TRUE, fig.cap="Concentration box plots",fig.subcap=c("\\texttt{boxConcMonth(eList)}","\\texttt{boxQTwice(eList, qUnit=1)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotBoxes, echo=TRUE, fig.cap="Concentration box plots"------------------
 boxConcMonth(eList)
 boxQTwice(eList,qUnit=1)
 
-## ----plotConcTime,echo=TRUE, fig.cap="The relation of concentration vs time or discharge",fig.subcap=c("\\texttt{plotConcTime(eList)}","\\texttt{plotConcQ(eList)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotConcTime,echo=TRUE, fig.cap="The relation of concentration vs time or discharge"----
 plotConcTime(eList)
 plotConcQ(eList, qUnit=1)
 
-## ----plotFluxQ,echo=TRUE, fig.cap="The relation of flux vs discharge",out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotFluxQ,echo=TRUE, fig.cap="The relation of flux vs discharge"---------
 plotFluxQ(eList, fluxUnit=4)
 
-## ----multiPlotDataOverview, echo=TRUE, fig.cap="\\texttt{multiPlotDataOverview(eList, qUnit=1)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----multiPlotDataOverview, echo=TRUE,out.width="100%", fig.cap="`multiPlotDataOverview(eList, qUnit=1)`"----
 multiPlotDataOverview(eList, qUnit=1)
 
-## ----flowDuration, echo=TRUE------------------------------
+## ----flowDuration, echo=TRUE--------------------------------------------------
 flowDuration(eList, qUnit=1)
 
 flowDuration(eList, qUnit=1, centerDate="09-30", span=30)
 
-## ----wrtds3, eval=FALSE, echo=TRUE------------------------
+## ----wrtds3, eval=FALSE, echo=TRUE--------------------------------------------
 #  eList <- modelEstimation(eList)
 
-## ----wrtds5, eval=FALSE, echo=TRUE------------------------
+## ----wrtds5, eval=FALSE, echo=TRUE--------------------------------------------
 #  #An example directory name
 #  savePath <- "C:/Users/egretUser/WRTDS_Output/"
 #  saveResults(savePath, eList)
 
-## ----wrtds8, eval=FALSE, echo=TRUE------------------------
+## ----wrtds8, eval=FALSE, echo=TRUE--------------------------------------------
 #  loadPath <- "C:/Users/egretUser/WRTDS_Output/"
 #  staAbbrev <- "Chop"
 #  constitAbbrev <- "NO3"
@@ -434,14 +399,14 @@ flowDuration(eList, qUnit=1, centerDate="09-30", span=30)
 #                      constitAbbrev,".RData")
 #  load(pathToFile)
 
-## ----getChopData1,echo=FALSE,eval=TRUE--------------------
+## ----getChopData1,echo=FALSE,eval=TRUE----------------------------------------
 # Sample <- getSample(eList)
 # Daily <- getDaily(eList)
 # INFO <- getInfo(eList)
 # surfaces <- getSurfaces(eList)
 eList <- Choptank_eList
 
-## ----plotConcTimeDaily, echo=TRUE, fig.cap="Concentration and flux vs time",fig.subcap=c("\\texttt{plotConcTimeDaily(2008, 2010)}","\\texttt{plotFluxTimeDaily(2008, 2010)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotConcTimeDaily, echo=TRUE, fig.cap="Concentration and flux vs time"----
 # Return to water year:
 eList <- setPA(eList)
 
@@ -451,101 +416,92 @@ yearEnd <- 2010
 plotConcTimeDaily(eList, yearStart, yearEnd)
 plotFluxTimeDaily(eList, yearStart, yearEnd)
 
-## ----plotFluxPred, echo=TRUE, fig.cap="Concentration and flux predictions",fig.subcap=c('\\texttt{plotConcPred(eList)}','\\texttt{plotFluxPred(eList)}'),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotFluxPred, echo=TRUE, fig.cap="Concentration and flux predictions"----
 plotConcPred(eList)
 plotFluxPred(eList)
 
-## ----plotResidQ, echo=TRUE, fig.cap="Residuals",fig.subcap=c("\\texttt{plotResidPred(eList)}","\\texttt{plotResidQ(eList, qUnit=1)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotResidQ, echo=TRUE, fig.cap="Residuals"-------------------------------
 plotResidPred(eList)
 plotResidQ(eList, qUnit=1)
 
-## ----boxResidMonth, echo=TRUE, fig.cap="Residuals with respect to time",fig.subcap=c("\\texttt{plotResidTime(eList)}","\\texttt{boxResidMonth(eList)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----boxResidMonth, echo=TRUE, fig.cap="Residuals with respect to time"-------
 plotResidTime(eList)
 boxResidMonth(eList)
 
-## ----boxConcThree, echo=TRUE, fig.cap="Default \\texttt{boxConcThree(eList)}",out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='asis',results='hide',fig.pos="h"----
+## ----boxConcThree, echo=TRUE, fig.cap="Default `boxConcThree(eList)`"---------
 boxConcThree(eList)
 
-## ----plotFluxHist, echo=TRUE, fig.cap="Concentration and flux history",fig.subcap=c("\\texttt{plotConcHist(eList)}", "\\texttt{plotFluxHist(eList)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotFluxHist, echo=TRUE, fig.cap="Concentration and flux history"--------
 plotConcHist(eList)
 plotFluxHist(eList)
 
-## ----plotConcQSmooth, echo=TRUE, fig.cap="Concentration vs. discharge",fig.subcap=c("\\texttt{plotConcQSmooth}","\\texttt{plotConcQSmooth(logScale=TRUE)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
-qLow <- 20
-qHigh <- 700
-date1 <- "2000-09-01"
-date2 <- "2005-09-01"
-date3 <- "2009-09-01"
-plotConcQSmooth(eList, date1, date2, date3,
-                qLow, qHigh, qUnit=1)
-plotConcQSmooth(eList, date1, date2, date3,
-                qLow, qHigh, qUnit=1,logScale=TRUE)
+## ----plotConcQSmooth, echo=TRUE, fig.cap="Concentration vs. discharge"--------
+# Multi-line plots:
+date1 <- "1985-09-01"
+date2 <- "1997-09-01"
+date3 <- "2010-09-01"
+qBottom <- 0.2
+qTop <- 10
+plotConcQSmooth(eList, date1, date2, date3, qBottom, qTop, 
+                   concMax=2,legendTop = 0.5)
 
-## ----plotConcTimeSmooth, echo=TRUE, fig.cap="\\texttt{plotConcTimeSmooth(eList))}",fig.subcap=c("\\texttt{plotConcTimeSmooth}","\\texttt{plotConcTimeSmooth(logScale=TRUE)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',results='hide',fig.pos="h"----
-q1 <- 10
-q2 <- 25
-q3 <- 75
+plotConcQSmooth(eList, date1, date2, date3,
+                qBottom, qTop, legendTop = 0.5,logScale=TRUE)
+
+## ----plotConcTimeSmooth, echo=TRUE, fig.cap="`plotConcTimeSmooth(eList))`"----
+q1 <- 2
+q2 <- 10
+q3 <- 20
 centerDate <- "07-01"
-plotConcTimeSmooth(eList, q1, q2, q3, centerDate, 2000, 2010)
+yearEnd <- 1980
+yearStart <- 2010
 plotConcTimeSmooth(eList, q1, q2, q3, centerDate, 
-                   2000, 2010,logScale=TRUE)
+                   yearStart, yearEnd, legendTop = 0.4)
 
-## ----fluxBiasMulti, echo=TRUE, fig.cap="\\texttt{fluxBiasMulti(eList, qUnit=1)}",fig.show='asis',fig.width=8, fig.height=10,fig.pos="h"----
+plotConcTimeSmooth(eList, q1, q2, q3, centerDate, 
+                   yearStart, yearEnd, 
+                   legendTop = 0.4,logScale=TRUE)
+
+## ----fluxBiasMulti, echo=TRUE, fig.cap="`fluxBiasMulti(eList, qUnit=1)`",fig.show='asis',fig.width=8, fig.height=10,fig.pos="h", out.width="100%"----
 fluxBiasMulti(eList, qUnit=1)
 
-## ----plotContours, echo=TRUE,fig.cap="\\texttt{plotContours(eList)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----plotContours,out.width="100%",fig.height=5, echo=TRUE,fig.cap="`plotContours(eList)`"----
 clevel<-seq(0,2,0.2)
-plotContours(eList, yearStart=2008,yearEnd=2010,qBottom=20,qTop=1000, 
-             contourLevels = clevel,qUnit=1)
+plotContours(eList, yearStart=1980,yearEnd=2010,qBottom=0.5,qTop=20, 
+             contourLevels = clevel)
 
-## ----plotDiffContours, echo=TRUE, fig.cap="\\texttt{plotDiffContours(eList)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
-plotDiffContours(eList, year0=2000,year1=2010,
-                 qBottom=20,qTop=1000,maxDiff=0.6,qUnit=1)
+## ----plotDiffContours, echo=TRUE,out.width="100%",fig.height=5, fig.cap="`plotDiffContours(eList)`"----
+plotDiffContours(eList, year0=1990,year1=2010,
+                 qBottom=0.5,qTop=20,maxDiff=0.6)
 
-## ----tableResults1, echo=TRUE, eval=FALSE-----------------
+## ----tableResults1, echo=TRUE, eval=FALSE-------------------------------------
 #  tableResults(eList)
 #  returnDF <- tableResults(eList)
 
-## ----tableResults2, echo=FALSE, eval=TRUE,results='hide'----
+## ----tableResults2, echo=FALSE, eval=TRUE,results='hide'----------------------
 returnDF <- tableResults(eList)
 
-## ----tableResultshead, echo=FALSE, results='asis'---------
-print(xtable(head(returnDF),
-       label="table:tableChangeHead",
-       caption="Table created from \\texttt{head(returnDF)}",
-       digits=c(0,0,2,3,3,3,3)),
-       caption.placement="top",
-       size = "\\footnotesize",
-       latex.environment=NULL,
-       sanitize.text.function = function(x) {x},
-       sanitize.colnames.function =  bold.colHeaders,
-       sanitize.rownames.function = addSpace
-      )
+## ----tableResultshead, echo=FALSE, results='asis'-----------------------------
+knitr::kable(head(returnDF),
+       caption="Table created from `head(returnDF)`",
+       digits=c(0,0,2,3,3,3,3))
 
-## ----tableChange1, eval=TRUE, echo=TRUE-------------------
+## ----tableChange1, eval=TRUE, echo=TRUE---------------------------------------
 tableChange(eList, yearPoints=c(2000,2005,2010))
 
-## ----tableChangeSingleR, eval=TRUE, echo=TRUE,results='hide'----
+## ----tableChangeSingleR, eval=TRUE, echo=TRUE,results='hide'------------------
 returnDF <- tableChangeSingle(eList, yearPoints=c(2000,2005,2010))
 
-## ----tableResultsShow, echo=FALSE, results='asis'---------
-print(xtable(returnDF,
-       label="tableChangeSingle",
-       caption="Table created from \\texttt{tableChangeSingle} function",
-       digits=c(0,0,0,3,2,1,1)),
-       caption.placement="top",
-       size = "\\footnotesize",
-       latex.environment=NULL,
-       sanitize.text.function = function(x) {x},
-       sanitize.colnames.function =  bold.colHeaders,
-       sanitize.rownames.function = addSpace
-      )
+## ----tableResultsShow, echo=FALSE, results='asis'-----------------------------
+knitr::kable(returnDF,
+       caption="Table created from `tableChangeSingle` function",
+       digits=c(0,0,0,3,2,1,1))
 
-## ----adjustSize,echo=TRUE,eval=TRUE,fig.cap="Modifying text and point size, as shown using the \\texttt{plotConcQ} function", fig.subcap=c("\\texttt{(cex.axis=2,cex.main=1.5)}","\\texttt{(cex.lab=2,cex=2)}"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----adjustSize,echo=TRUE,eval=TRUE,fig.cap="Modifying text and point size, as shown using the `plotConcQ` function"----
 plotConcQ(eList, cex.axis=2,cex.main=1.5,logScale=TRUE)
 plotConcQ(eList, cex.lab=2,cex=2,logScale=TRUE)
 
-## ----plotConcQComparison,echo=TRUE,eval=TRUE,fig.cap="Modified \\texttt{plotConcQ}", fig.subcap=c("Default","Modified"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h"----
+## ----plotConcQComparison,echo=TRUE,eval=TRUE,fig.cap="Modified `plotConcQ`"----
 plotConcQ(eList, logScale=TRUE)
 par(mar=c(8,8,8,8))
 plotConcQ(eList, customPar=TRUE,col="blue",cex=1.1,
@@ -556,13 +512,13 @@ legend(4.5,.09,"Choptank Nitrogen", pch=18, col="blue",bg="white")
 arrows(3, 0.14, 1, .05,lwd=2)
 text(12,.14,"Censored Value")
 
-## ----easyFontChange,echo=TRUE,eval=TRUE,fig.cap="Serif font",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth', fig.pos="h"----
+## ----easyFontChange,echo=TRUE,eval=TRUE,fig.cap="Serif font"------------------
 # Switching to serif font:
 par(family="serif")
 plotFluxPred(eList, customPar=TRUE)
 mtext(side=3,line=-3,"Serif font example",cex=3)
 
-## ----modifiedContour1,echo=TRUE,eval=TRUE,fig.cap="Contour plot with modified axis and color scheme",fig.show='hold',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----modifiedContour1,echo=TRUE,eval=TRUE,fig.cap="Contour plot with modified axis and color scheme", out.width="100%",fig.height=5----
 colors <- colorRampPalette(c("white","black"))
 yTicksModified <- c(.5,1,10,25)
 plotContours(eList, 2001,2010,0.5,50, 
@@ -572,7 +528,7 @@ plotContours(eList, 2001,2010,0.5,50,
              flowDuration=FALSE,
              tcl=0.2,tick.lwd=2.5)  
 
-## ----modifiedDiffContour,echo=TRUE,eval=TRUE,fig.cap="Difference contour plot with modified color scheme",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----modifiedDiffContour,echo=TRUE,eval=TRUE,fig.cap="Difference contour plot with modified color scheme",out.width="100%",fig.height=5----
 colors <- colorRampPalette(c("yellow","white","blue"))
 maxDiff<-0.6
 par(oma=c(1,1,1,1))
@@ -581,7 +537,7 @@ plotDiffContours(eList, year0=2001,year1=2010,qBottom=0.5,qTop=50,
              color.palette=colors,
              flowDuration=FALSE, customPar=TRUE)
 
-## ----tinyPlot1,echo=TRUE,eval=TRUE,fig.cap="Custom multipanel plot using tinyPlot",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----tinyPlot1,echo=TRUE,eval=TRUE,fig.cap="Custom multipanel plot using tinyPlot", out.width="100%"----
 par(mfcol = c(2, 2), oma = c(0, 1.7, 6, 1.7))
 
 plotFluxQ(eList, tinyPlot=TRUE,printTitle=FALSE,
@@ -591,7 +547,7 @@ plotFluxHist(eList, tinyPlot=TRUE,printTitle=FALSE,fluxMax=1)
 plotConcHist(eList, tinyPlot=TRUE,printTitle=FALSE,concMax=3)
 mtext("Custom multi-pane graph using tinyPlot=TRUE", outer=TRUE, font=2)
 
-## ----customPanel,echo=TRUE,eval=TRUE,fig.cap="Custom multipanel plot",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
+## ----customPanel,echo=TRUE,eval=TRUE,fig.cap="Custom multipanel plot", out.width="100%"----
 par(mar=c(3.5,3.5,0.2,0.2), # whitespace around the plots
     oma=c(1,1,3,1), # outer margin
     mgp=c(2,0.5,0), # spacing between the label numbers and plots
@@ -613,27 +569,29 @@ plotConcHist(eList, tinyPlot=TRUE,printTitle=FALSE,concMax=3,
           showYLabels=FALSE, showYAxis=FALSE, customPar=TRUE)
 mtext("Custom multi-pane graph using customPar", outer=TRUE, font=2)
 
-## ----helpFunc,eval = FALSE--------------------------------
+## ----helpFunc,eval = FALSE----------------------------------------------------
 #  ?plotConcQ
 
-## ----rawFunc,eval = FALSE---------------------------------
+## ----rawFunc,eval = FALSE-----------------------------------------------------
 #  plotConcQ
 
-## ----installFromCran,eval = FALSE-------------------------
+## ----installFromCran,eval = FALSE---------------------------------------------
 #  install.packages("EGRET")
 
-## ----openLibraryTest, eval=FALSE--------------------------
+## ----openLibraryTest, eval=FALSE----------------------------------------------
 #  library(EGRET)
 
-## ----label=getSiteApp, echo=TRUE,eval=TRUE----------------
-
+## ----label=getSiteApp, echo=TRUE,eval=TRUE------------------------------------
 tableData <- tableResults(eList)
 
-## ----label=saveData, echo=TRUE, eval=FALSE----------------
+## ----label=saveData, echo=TRUE, eval=FALSE------------------------------------
 #  write.table(tableData, file="tableData.tsv",sep="\t",
 #              row.names = FALSE,quote=FALSE)
 
-## ----label=savePlots, echo=TRUE, eval=FALSE---------------
+## ----getTable, echo = FALSE---------------------------------------------------
+knitr::include_graphics("table1.png")
+
+## ----label=savePlots, echo=TRUE, eval=FALSE-----------------------------------
 #  jpeg("plotFlowSingle.jpg")
 #  plotFlowSingle(eList, 1)
 #  dev.off()
@@ -659,7 +617,7 @@ tableData <- tableResults(eList)
 #  dev.off()
 #  
 
-## ----label=savePlots2, echo=TRUE, eval=FALSE--------------
+## ----label=savePlots2, echo=TRUE, eval=FALSE----------------------------------
 #  postscript("fluxBiasMulti.ps", height=10,width=8)
 #  fluxBiasMulti(eList)
 #  dev.off()
